@@ -1,24 +1,21 @@
 #!/usr/bin/env python
 
-#    Copyright 2014 Mikko Korpela
+#  Copyright 2014 Mikko Korpela
 #
-#    This file is part of Pabot - A parallel executor for Robot Framework test cases..
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
-#    Pabot is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
+#      http://www.apache.org/licenses/LICENSE-2.0
 #
-#    Pabot is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with Pabot.  If not, see <http://www.gnu.org/licenses/>.
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 #
 #  partly based on work by Nokia Solutions and Networks Oyj
-#  that was licensed under Apache License Version 2.0
+
 
 
 import os, sys, time, datetime
@@ -99,6 +96,8 @@ def _options_for_executor(options, outs_dir, suite_name):
     options['suite'] = suite_name
     options['outputdir'] = outs_dir
     options['monitorcolors'] = 'off'
+    options['variable'] = options.get('variable')
+    options['variable'].append('PABOTLIBURI:127.0.0.1:8270')
     if ROBOT_VERSION >= '2.8':
         options['monitormarkers'] = 'off'
     return options
